@@ -126,7 +126,7 @@ char *make_options_string(char *path, int pipefd, char *extra)
 
 	options = malloc(MAX_OPTIONS_LEN + 1);
 	if (!options) {
-		crit(LOGOPT_ANY, "can't malloc options string");
+		logerr("can't malloc options string");
 		return NULL;
 	}
 
@@ -141,13 +141,12 @@ char *make_options_string(char *path, int pipefd, char *extra)
 			AUTOFS_MAX_PROTO_VERSION);
 
 	if (len >= MAX_OPTIONS_LEN) {
-		crit(LOGOPT_ANY, "buffer to small for options - truncated");
+		logerr("buffer to small for options - truncated");
 		len = MAX_OPTIONS_LEN - 1;
 	}
 
 	if (len < 0) {
-		crit(LOGOPT_ANY,
-		     "failed to malloc autofs mount options for %s", path);
+		logerr("failed to malloc autofs mount options for %s", path);
 		free(options);
 		return NULL;
 	}
@@ -163,7 +162,7 @@ char *make_mnt_name_string(char *path)
 
 	mnt_name = malloc(MAX_MNT_NAME_LEN + 1);
 	if (!mnt_name) {
-		crit(LOGOPT_ANY, "can't malloc mnt_name string");
+		logerr("can't malloc mnt_name string");
 		return NULL;
 	}
 
@@ -171,13 +170,12 @@ char *make_mnt_name_string(char *path)
 			mnt_name_template, (unsigned) getpid());
 
 	if (len >= MAX_MNT_NAME_LEN) {
-		crit(LOGOPT_ANY, "buffer to small for mnt_name - truncated");
+		logerr("buffer to small for mnt_name - truncated");
 		len = MAX_MNT_NAME_LEN - 1;
 	}
 
 	if (len < 0) {
-		crit(LOGOPT_ANY,
-		     "failed setting up mnt_name for autofs path %s", path);
+		logerr("failed setting up mnt_name for autofs path %s", path);
 		free(mnt_name);
 		return NULL;
 	}
@@ -207,7 +205,7 @@ struct mnt_list *get_mnt_list(const char *table, const char *path, int include)
 	tab = setmntent(table, "r");
 	if (!tab) {
 		char *estr = strerror_r(errno, buf, PATH_MAX - 1);
-		error(LOGOPT_ANY, "setmntent: %s", estr);
+		logerr("setmntent: %s", estr);
 		return NULL;
 	}
 
@@ -398,7 +396,7 @@ int is_mounted(const char *table, const char *path, unsigned int type)
 	tab = setmntent(table, "r");
 	if (!tab) {
 		char *estr = strerror_r(errno, buf, PATH_MAX - 1);
-		error(LOGOPT_ANY, "setmntent: %s", estr);
+		logerr("setmntent: %s", estr);
 		return 0;
 	}
 
@@ -443,7 +441,7 @@ int has_fstab_option(const char *opt)
 	tab = setmntent(_PATH_MNTTAB, "r");
 	if (!tab) {
 		char *estr = strerror_r(errno, buf, PATH_MAX - 1);
-		error(LOGOPT_ANY, "setmntent: %s", estr);
+		logerr("setmntent: %s", estr);
 		return 0;
 	}
 
@@ -471,7 +469,7 @@ char *find_mnt_ino(const char *table, dev_t dev, ino_t ino)
 	tab = setmntent(table, "r");
 	if (!tab) {
 		char *estr = strerror_r(errno, buf, (size_t) PATH_MAX - 1);
-		error(LOGOPT_ANY, "setmntent: %s", estr);
+		logerr("setmntent: %s", estr);
 		return 0;
 	}
 
@@ -667,7 +665,7 @@ struct mnt_list *tree_make_mnt_tree(const char *table, const char *path)
 	tab = setmntent(table, "r");
 	if (!tab) {
 		char *estr = strerror_r(errno, buf, PATH_MAX - 1);
-		error(LOGOPT_ANY, "setmntent: %s", estr);
+		logerr("setmntent: %s", estr);
 		return NULL;
 	}
 
